# ping.rb Japanese resources

if /conf/ =~ @mode then
	@ping_label_conf = ''
	@ping_label_list = 'ꥹ'
	@ping_label_list_desc = 'Τ򤹤pingӥURL1ԤˤĤ1ϤƤʤޤꤿꤹȡǥॢȤƤޤΤޤ'
	@ping_label_timeout = 'ॢ()'
end

@ping_label_send = ''
